==> haskell-blaze-markup-0.7.0.3-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.0.3
id: blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d
key: blaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: 75ae18e66b257e9c955cb8248c8118e2
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/blaze-markup-0.7.0.3
hs-libraries: HSblaze-markup-0.7.0.3-6iLNhqMnSkpL7LEeNEW58d
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.7.1.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: blaze-markup
version: 0.7.1.0
id: blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp
key: blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp
license: BSD3
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
synopsis: A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier, Deepak Jois
exposed: True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8
abi: 1c4db92aa5fd7c50d87a748c76436239
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.1.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/blaze-markup-0.7.1.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/blaze-markup-0.7.1.0
hs-libraries: HSblaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
haddock-interfaces: /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock
haddock-html: /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
